#!/bin/bash
# Checks out or creates a new branch from master if the target branch name is not one of the default ones
# Arguments:
#  - $1: path to the config
#  - $2: target branch name
#  - $3 and onwards: default branches names

set -o errexit
set -o nounset
set -o pipefail

CI_SCRIPTS_ROOT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
source "$CI_SCRIPTS_ROOT/include/utils.sh"

if [[ "$#" -lt 3 ]]; then
    echo "Usage: $0 <orchestra configuration path> <target branch> <default branch> [<default branch>, ...]"
    exit 1
fi
CONFIG_PATH="$1" && shift
TARGET_BRANCH="$1" && shift
while [[ $# -gt 0 ]]; do
    DEFAULT_BRANCHES+=($1)
    shift
done
if ! [[ -e "$CONFIG_PATH" ]]; then
    log_err "$CONFIG_PATH does not exist"
    exit 1
fi

cd "$CONFIG_PATH"

for DEFAULT_BRANCH in "${DEFAULT_BRANCHES[@]}"; do
    if [[ "$TARGET_BRANCH" == "$DEFAULT_BRANCH" ]]; then
        log "Target branch $TARGET_BRANCH is a default branch"
        exit 0
    fi
done

if git rev-parse --quiet --verify "$TARGET_BRANCH" >/dev/null; then
    log "Checking out branch $TARGET_BRANCH for orchestra configuration"
    git checkout "$TARGET_BRANCH"
else
    log "Creating branch $TARGET_BRANCH for orchestra configuration from master"
    git checkout -b "$TARGET_BRANCH" master
fi
