#!/bin/bash
# This script clones the given repo and checks out the correct branch from a list
# Arguments:
#  - $1: repo URL
#  - $2: path where the repo has to be cloned
#  - $3 and next: list of branches to checkout

set -o errexit
set -o nounset
set -o pipefail

CI_SCRIPTS_ROOT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
source "$CI_SCRIPTS_ROOT/include/utils.sh"

if [[ $# -lt 3 ]]; then
    echo "Usage: clone_and_checkout_repo.sh <repo URL> <path> <branch> [<branch>, ...]"
    exit 1
fi

REPO_URL="$1" && shift
CHECKOUT_PATH="$1" && shift
BRANCH_LIST=()
while [[ $# -ge 1 ]]; do
    BRANCH_LIST+=("$1")
    shift
done

if [[ -e "$CHECKOUT_PATH" ]]; then
    echo "$CHECKOUT_PATH already exists"
    exit 1
fi

log "Cloning $REPO_URL into $CHECKOUT_PATH"
mkdir -p "$(dirname "$CHECKOUT_PATH")"
git clone "$REPO_URL" "$CHECKOUT_PATH"
cd "$CHECKOUT_PATH"

# Try checking out all the branches one by one
for BRANCH_TO_TRY in "${BRANCH_LIST[@]}"; do
    if git checkout "$BRANCH_TO_TRY" &> /dev/null; then
        BRANCH="$BRANCH_TO_TRY"
        break
    fi
done

if [[ -z "$BRANCH" ]]; then
    echo "Could not checkout any branch (tried ${BRANCH_LIST[*]})"
    exit 1
fi

log "Checked out branch $BRANCH"
