#!/bin/bash
# Sets up user_options.yml
# Arguments:
#  - $1: path to the config
#  - $2: path to the user options template
#  - $3: default build for revng core components
#  - $4 and onwards: list of branch names to try when cloning projects

set -o errexit
set -o nounset
set -o pipefail

CI_SCRIPTS_ROOT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
source "$CI_SCRIPTS_ROOT/include/utils.sh"

if [[ $# -le 4 ]]; then
    log_err "Wrong number of arguments"
    exit 1
fi

CONFIG_PATH="$1"; shift
USER_OPTIONS_TEMPLATE_PATH="$1"; shift
REVNG_COMPONENTS_DEFAULT_BUILD="$1"; shift
BRANCHES_TO_TRY=()
while [[ $# -gt 0 ]]; do
    BRANCHES_TO_TRY+=("$1")
    shift
done

USER_OPTIONS_PATH="$CONFIG_PATH/.orchestra/config/user_options.yml"
if [[ -e "$USER_OPTIONS_PATH" ]]; then
    log_err "$USER_OPTIONS_PATH already exists!"
    exit 1
fi

REMOTE="$(git -C "$CONFIG_PATH" remote get-url origin | sed 's|^\([^:]*:\)\([^/]\)|\1/\2|')"
GITLAB_ROOT="$(dirname "$(dirname "$REMOTE")")"
cat "$USER_OPTIONS_TEMPLATE_PATH" | sed "s|%GITLAB_ROOT%|$GITLAB_ROOT|" > "$USER_OPTIONS_PATH"

# Build branches list
cat >> "$USER_OPTIONS_PATH" <<EOF
#@overlay/replace
branches:
EOF
for BRANCH in "${BRANCHES_TO_TRY[@]}"; do
    echo "  - $BRANCH" >> "$USER_OPTIONS_PATH";
done

# Set default builds
echo "#@overlay/replace" >> "$USER_OPTIONS_PATH"
echo "revng_components_default_build: $REVNG_COMPONENTS_DEFAULT_BUILD" >> "$USER_OPTIONS_PATH"

log "User options:"
cat "$USER_OPTIONS_PATH"
